<?php

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
/**
 *
 * Header Widget . 
 *
 */
class Taxseco_Header extends Widget_Base {

	public function get_name() {
		return 'taxsecoheader';
	}
	public function get_title() {
		return __( 'Header V2', 'taxiar' ); 
	}

	public function get_icon() {
		return 'th-icon';
    }

	public function get_categories() {
		return [ 'taxiar_header_elements' ];
	}
	protected function register_controls() {

		$this->start_controls_section(
			'header_section',
			[
				'label' 	=> __( 'Header', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );
        $this->add_control(
			'header_style',
			[
				'label' 		=> __( 'Header Style', 'taxiar' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options' 		=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2' 		=> __( 'Style Two', 'taxiar' ),
					'3' 		=> __( 'Style Three', 'taxiar' ),
				],
			]
		);


		$this->add_control(
			'show_header_top',
			[
				'label' 		=> __( 'Show Top Bar?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);

		$this->add_control(
			'show_middle_bar',
			[
				'label' 		=> __( 'Show Middle Bar?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);

		$this->add_control(

			'header_top_middle_bg_image',

			[
				'label' 		=> __( 'Header Top Middle BG Image', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);


		$this->add_control(
			'topbar_slogan',
			[
				'label' 		=> __( 'Topbar Slogan', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Welcome to Taxseco Online Taxi Services', 'taxiar' ),
				'condition'		=> [ 'show_header_top' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'header_top_right_text_icon',
			[
				'label' 		=> __( 'Button Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '<i class="far fa-user"></i>', 'taxiar' ),
				'condition'		=> [ 'show_header_top' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'header_top_right_text',
			[
				'label' 		=> __( 'Button Text', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Customer Sign In', 'taxiar' ),
				'condition'		=> [ 'show_header_top' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'header_top_right_text_link',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition'		=> [ 'show_header_top' => [ 'yes' ] ],
			]
		);

		//----------------------------header middle control---------------------------//

		$this->add_control(
			'email_icon',
			[
				'label' 		=> __( 'Email Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '<i class="icon-btn fas fa-envelope"></i>', 'taxiar' ),
				'condition'		=> [ 'show_middle_bar' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'email',
			[
				'label' 		=> __( 'Email', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'info@anob-taxi.com', 'taxiar' ),
				'condition'		=> [ 'show_middle_bar' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'phone_icon',
			[
				'label' 		=> __( 'Phone Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '<i class="icon-btn fas fa-phone"></i>', 'taxiar' ),
				'condition'		=> [ 'show_middle_bar' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'phone',
			[
				'label' 		=> __( 'Phone', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '(+49) 0011-52256', 'taxiar' ),
				'condition'		=> [ 'show_middle_bar' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'address_icon',
			[
				'label' 		=> __( 'Address Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '<i class="icon-btn fas fa-location-dot"></i>', 'taxiar' ),
				'condition'		=> [ 'show_middle_bar' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'address',
			[
				'label' 		=> __( 'Address', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '245, Frankfurt. Germany', 'taxiar' ),
				'condition'		=> [ 'show_middle_bar' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'address_url',
			[
				'label' 		=> __( 'Address Url', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '#', 'taxiar' ),
				'condition'		=> [ 'show_middle_bar' => [ 'yes' ] ],
			]
		);
		$this->add_control(
			'show_language',
			[
				'label' 		=> __( 'Show Language?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);
		$this->add_control(
			'show_social',
			[
				'label' 		=> __( 'Show Social?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);
		$this->add_control(
			'social_text',
			[
				'label' 		=> __( 'Socail Text', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Follow Us:', 'taxiar' ),
				'condition'		=> [ 
					'show_middle_bar' => [ 'yes' ],
					'show_social' => [ 'yes' ],
					'header_style' => [ '3' ],
				],
			]
		);
		$repeater = new Repeater();

		$repeater->add_control(
			'social_icon',
			[
				'label' 	=> __( 'Social Icon', 'taxiar' ),
				'type' 		=> Controls_Manager::ICONS,
				'default' 	=> [
					'value' 	=> 'fab fa-facebook-f',
					'library' 	=> 'solid',
				],
			]
		);

		$repeater->add_control(
			'icon_link',
			[
				'label' 		=> __( 'Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$this->add_control(

			'social_icon_list',
			[
				'label' 		=> __( 'Social Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'social_icon' => __( 'Add Social Icon','taxiar' ),
					],
				],
				'condition'		=> [ 
					'show_middle_bar' => [ 'yes' ],
					'show_social' => [ 'yes' ],
				],
			]
		);

		//----------------------------maim menu control----------------------------//

		$this->add_control(

			'logo_image',

			[
				'label' 		=> __( 'Upload Logo', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'logo_bg_image',

			[
				'label' 		=> __( 'Upload Logo Background Image', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$menus = $this->taxseco_menu_select();

		if( !empty( $menus ) ){
	        $this->add_control(
				'taxseco_menu_select',
				[
					'label'     	=> __( 'Select Taxseco Menu', 'taxiar' ),
					'type'      	=> Controls_Manager::SELECT,
					'options'   	=> $menus,
					'description' 	=> sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'taxiar' ), admin_url( 'nav-menus.php' ) ),
				]
			);
		}else {
			$this->add_control(
				'no_menu',
				[
					'type' 				=> Controls_Manager::RAW_HTML,
					'raw' 				=> '<strong>' . __( 'There are no menus in your site.', 'taxiar' ) . '</strong><br>' . sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'taxiar' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
					'separator' 		=> 'after',
					'content_classes' 	=> 'elementor-panel-alert elementor-panel-alert-info',
				]
			);
		}


		$this->add_control(
			'show_search_btn',
			[
				'label' 		=> __( 'Show Search ?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);
		$this->add_control(
			'button_text',
			[
				'label' 		=> __( 'Button Text', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'button_url',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);
		$this->add_control(
			'off_canvas',
			[
				'label' 		=> __( 'Show Off Canvas ?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);
		$this->add_control(
			'off_canvas_icon',
			[
				'label' 		=> __( 'Offcanvas Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( '<i class="fa-solid fa-grid"></i>', 'taxiar' ),
				'condition'		=> [ 'off_canvas' => [ 'yes' ] ],
			]
		);

        $this->end_controls_section();
       //-----------------------------------Topbar Styling-------------------------------------//
        $this->start_controls_section(
			'topbar_styling',
			[
				'label'     => __( 'General Styling', 'taxiar' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'topbar_background_color',
			[

				'label'     => __( 'Top Background Color', 'taxiar' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-top' => 'background-color: {{VALUE}}!important',
                ],
			]
        );
        $this->add_control(
			'menu_background_color2',
			[

				'label'     => __( 'Menu Top Background Color', 'taxiar' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-layout2 .menu-top' => 'background-color: {{VALUE}}!important',
                ],
				'condition'		=> [ 
					'header_style' => [ '1' ],
				],
			]
        );
        $this->add_control(
			'menu_background_color',
			[

				'label'     => __( 'Menu Background Color', 'taxiar' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .menu-area' => 'background-color: {{VALUE}}!important',
                ],
			]
        );
        $this->add_control(
			'logo_background_color',
			[

				'label'     => __( 'Logo Background Color', 'taxiar' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header-layout2 .logo-shape,{{WRAPPER}} .header-layout1 .logo-shape, {{WRAPPER}} .header-layout3 .header-logo' => 'background-color: {{VALUE}}!important',
                ],
			]
        );

        
        $this->end_controls_section();

        //-----------------------------------Menubar Styling-------------------------------------//
        $this->start_controls_section(
			'menubar_styling',
			[
				'label'     => __( 'Menubar Styling', 'taxiar' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'top_level_menu_txt_color',
			[
				'label' 			=> __( 'Menu Text Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu ul > li > a' => 'color: {{VALUE}} !important;',
                ]
			]
        );
        $this->add_control(
			'top_level_menu_hover_color',
			[
				'label' 			=> __( 'Menu Hover Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu > ul > li > a:hover' => 'background-color: {{VALUE}} !important;',
                ]
			]
        );
        $this->add_control(
			'top_level_menu_hover_txt_color',
			[
				'label' 			=> __( 'Menu Hover Text Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu ul > li > a:hover' => 'color: {{VALUE}} !important;',
                ]
			]
        );
        $this->add_control(
			'top_level_menu_hover_bottom_color',
			[
				'label' 			=> __( 'Menu Bottom Hover Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .menu-style1 > ul > li > a::before' => 'background-color: {{VALUE}} !important;',
                ]
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 			=> 'top_level_menu_typography',
				'label' 		=> __( 'Menu Typography', 'taxiar' ),
                'selector' 		=> '{{WRAPPER}} .main-menu ul > li > a',
			]
		);

        $this->add_responsive_control(
			'top_level_menu_margin',
			[
				'label' 		=> __( 'Menu Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .main-menu ul > li > a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ]
			]
        );

        $this->add_responsive_control(
			'top_level_menu_padding',
			[
				'label' 		=> __( 'Menu Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .main-menu ul > li > a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ]
			]
		);

		$this->add_control(
			'top_level_menu_height',
			[
				'label' 		=> __( 'Height', 'taxiar' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px' ],
				'range' 	=> [
					'px' 	=> [
						'min' 	=> 0,
						'step' 	=> 1,
						'max'	=> 500
					],
				],
				'selectors' => [
					'{{WRAPPER}} .main-menu ul > li > a' => 'height: {{SIZE}}{{UNIT}} !important;line-height: {{SIZE}}{{UNIT}} !important;'
                ]
			]
		);
		$this->end_controls_section();
    }

    public function taxseco_menu_select(){
	    $taxseco_menu = wp_get_nav_menus();
	    $menu_array  = array();
		$menu_array[''] = __( 'Select A Menu', 'taxiar' );
	    foreach( $taxseco_menu as $menu ){
	        $menu_array[ $menu->slug ] = $menu->name;
	    }
	    return $menu_array;
	}

	protected function render() {

        $settings = $this->get_settings_for_display();

        $taxseco_avaiable_menu   = $this->taxseco_menu_select();

		if( ! $taxseco_avaiable_menu ){
			return;
		}

		$args = [
			'menu' 			=> $settings['taxseco_menu_select'],
			'menu_class' 	=> 'taxseco-menu',
			'container' 	=> '',
		];

		global $woocommerce;

		$user_id                   = get_current_user_id();
        $user                      = get_user_by('ID', $user_id);

		//Mobile menu, Offcanvas, Search
        echo taxiar_mobile_menu();
		echo taxiar_header_cart_offcanvas();
		echo taxiar_header_offcanvas();
		echo taxiar_search_box();

		// Header sub-menu icon
		if( class_exists( 'ReduxFramework' ) ){ 
			if(taxiar_opt('taxiar_menu_icon')){
				$menu_icon = '';
			}else{
				$menu_icon = 'hide-icon';
			}
		}

	    if($settings['header_style'] == 1) {
		    echo '<div class="th-header header-layout2">';
                	if( ! empty( $settings['header_top_middle_bg_image']['url'] ) ){
					 	echo '<div class="top-area" data-bg-src="'.esc_url( $settings['header_top_middle_bg_image']['url'] ).'">';
					}  

		        	if( $settings['show_header_top'] == 'yes' ){
			            echo '<div class="header-top">';
			                echo '<div class="container">';
			                    echo '<div class="row justify-content-center justify-content-md-between align-items-center">';
			                    	if(!empty($settings['topbar_slogan'])){
				                        echo '<div class="col-auto">';
				                            echo '<p class="header-notice">'.esc_html($settings['topbar_slogan']).'</p>';
				                        echo '</div>';
				                    }
									if( !empty($settings['header_top_right_text']) ){

										if(is_user_logged_in()){ 
											echo '<div class="col-auto d-none d-md-block">';
												echo '<div class="dropdown-link">';
													echo '<a class="dropdown-toggle" href="'.esc_url('#').'" role="button" id="dropdownMenuLink1" data-bs-toggle="dropdown" aria-expanded="false">';
														echo '<i class="far fa-user"></i>';
														echo esc_html(' Hello ', 'tnews') . esc_html($user->display_name);
													echo '</a>';
													echo '<ul class="dropdown-menu" aria-labelledby="dropdownMenuLink1">';
														echo '<li>';
															echo '<a href="'.get_permalink( get_option('woocommerce_myaccount_page_id') ).'">'.esc_html('Dashboard', 'tnews').'</a>';
															echo '<a href="'.esc_url( wp_logout_url() ).'">'.esc_html('Logout', 'tnews').'</a>';
														echo '</li>';
													echo '</ul>';
												echo '</div>';
											echo '</div>';
										}else{
											echo '<div class="col-auto d-none d-md-block">';
												echo '<div class="header-links">';
													echo '<ul>';
														echo '<li>'.wp_kses_post($settings['header_top_right_text_icon']).'<a href="'.esc_url( $settings['header_top_right_text_link']['url'] ).'">'.esc_html($settings['header_top_right_text']).'</a></li>';
													echo '</ul>';
												echo '</div>';

											echo '</div>';
										}
									}

			                    echo '</div>';
			                echo '</div>';
			            echo '</div>';
			        }

			        if( $settings['show_middle_bar'] == 'yes' ){
			        	$email    	= $settings['email'];
			        	$phone    	= $settings['phone'];

		                $email          = is_email( $email );

		                $replace        = array(' ','-',' - ');
		                $with           = array('','','');

		                $emailurl       = str_replace( $replace, $with, $email );
		                $phoneurl       = str_replace( $replace, $with, $phone );

			            echo '<div class="menu-top">';
			                echo '<div class="container">';
			                    echo '<div class="row align-items-center justify-content-center justify-content-sm-between">';
			                        echo '<div class="col-auto d-none d-sm-block">';


				                        if(!empty($phone)){	    
				                            echo '<a class="header-link" href="'.esc_attr( 'tel:'.$phoneurl ).'"><span class="icon-btn">'.wp_kses_post($settings['phone_icon']).'</span>'.esc_html($phone).'</a>';
				                        }
				                        if(!empty($email)){	 
				                            echo '<a class="header-link d-none d-lg-inline-block" href="'.esc_attr( 'mailto:'.$emailurl ).'"><span class="icon-btn">'.wp_kses_post($settings['email_icon']).'</span>'.esc_html($email).'</a>';
				                        }
				                        if(!empty($settings['address'])){	
				                            echo '<a class="header-link d-none d-xl-inline-block" href="'.esc_url($settings['address_url']).'"><span class="icon-btn">'.wp_kses_post($settings['address_icon']).'</span>'.esc_html($settings['address']).'</a>';
				                        }
			                        echo '</div>';
			                        if( ! empty( $settings['social_icon_list'] ) ){
				                        echo '<div class="col-auto">';
				                            echo '<div class="th-social">';
				                                foreach( $settings['social_icon_list'] as $social_icon ){
						                          	$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
						                          	$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';

						                            echo '<a '.wp_kses_post( $social_target.$social_nofollow ).' href="'.esc_url( $social_icon['icon_link']['url'] ).'">';

						                            \Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] );

						                          	echo '</a> ';
						                      	}
				                            echo '</div>';
				                        echo '</div>';
				                    }
			                    echo '</div>';
			                echo '</div>';
			            echo '</div>';
			        }

		        echo '</div>';
		        echo '<div class="sticky-wrapper">'; 
		            echo '<div class="menu-area">';
						echo '<div class="container">';
							echo '<div class="row align-items-center justify-content-between">';
								if( ! empty( $settings['logo_image']['url'] ) ){
									echo '<div class="col-auto">';
										echo '<div class="header-logo">';
											echo '<a href="'.esc_url( home_url( '/' ) ).'">';
												echo taxiar_img_tag( array(
													'url' => esc_url( $settings['logo_image']['url'] ),
												) );
											echo '</a>';

										echo '</div>';
									echo '</div>';
								}
								echo '<div class="col-auto">';
									echo '<div class="row align-items-center justify-content-between">';
										echo '<div class="col-auto">';
											echo '<nav class="main-menu d-none d-lg-inline-block '.esc_attr($menu_icon).'">';
												if( ! empty( $settings['taxseco_menu_select'] ) ){
													wp_nav_menu( $args );
												} 
											echo '</nav>';
											echo '<button type="button" class="th-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>';
										echo '</div>';
										echo '<div class="col-auto d-none d-xxl-block">';
											echo '<div class="header-button">';
												if( $settings['show_search_btn'] == 'yes' ){
													echo '<button type="button" class="icon-style2 searchBoxToggler"><i class="far fa-search"></i></button>';
												}

												if(!empty($settings['button_text'])){
													echo '<a href="'.esc_url( $settings['button_url']['url'] ).'" class="th-btn 2 style6 style-skew"><span class="btn-text">'.esc_html($settings['button_text']).'</span></a>';
												}
												if( $settings['off_canvas'] == 'yes' ){
													echo '<a href="'.esc_url('#').'" class="simple-icon sideMenuToggler">'.wp_kses_post($settings['off_canvas_icon']).'</a>';
												}

											echo '</div>';
										echo '</div>';
									echo '</div>';
								echo '</div>';
							echo '</div>';
						echo '</div>';		                    
						if( ! empty( $settings['logo_bg_image']['url'] ) ){
							echo '<div class="logo-shape" data-bg-src="'.esc_url( $settings['logo_bg_image']['url'] ).'"></div>';
						} 		                    
					echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}elseif($settings['header_style'] == 3) {
			?>
			<div class="th-header header-layout1">
				<?php if( $settings['show_header_top'] == 'yes' ): 

			    	$email    	= $settings['email'];
			    	$phone    	= $settings['phone'];

			        $email          = is_email( $email );

			        $replace        = array(' ','-',' - ');
			        $with           = array('','','');

			        $emailurl       = str_replace( $replace, $with, $email );
			        $phoneurl       = str_replace( $replace, $with, $phone );
					?>
		        <div class="header-top">
		            <div class="container">
		                <div class="row justify-content-center justify-content-md-between align-items-center gy-2">
		                    <div class="col-auto d-none d-md-block">
		                        <div class="header-links">
		                            <ul>
		                            	<?php if(!empty($phone)): ?>
		                                <li>
		                                	<?php echo wp_kses_post($settings['phone_icon']); ?>
		                                	<a href="<?php echo esc_attr( 'tel:'.$phoneurl ); ?>"><?php echo esc_html($phone); ?></a>
		                                </li>
		                                <?php endif; ?>
		                                <?php if(!empty($settings['address'])): ?>
		                                <li class="d-none d-xl-inline-block">
		                                	<?php echo wp_kses_post($settings['address_icon']); ?>
		                                	<a href="<?php echo esc_url($settings['address_url']); ?>"><?php echo esc_html($settings['address']); ?></a>
		                                </li>
		                                <?php endif; ?>
		                                <?php if(!empty($email)): ?>
		                                <li>
		                                	<?php echo wp_kses_post($settings['email_icon']); ?>
		                                	<a href="<?php echo esc_attr( 'mailto:'.$emailurl ); ?>"><?php echo esc_html($email); ?></a>
		                                </li>
		                                <?php endif; ?>
		                            </ul>
		                        </div>
		                    </div>
		                    <div class="col-auto">
		                        <div class="header-links">
		                            <ul>
		                            	<?php if( ! empty( $settings['show_language'] ) ): ?>
		                                <li class="d-none d-lg-inline-block">
		                                    <div class="dropdown-link">
		                                        <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink1" data-bs-toggle="dropdown" aria-expanded="false"><?php echo esc_html__('Language', 'taxiar'); ?></a>
		                                        <ul class="dropdown-menu" aria-labelledby="dropdownMenuLink1">
		                                            <li>
		                                               <?php echo do_shortcode('[gtranslate]'); ?>
		                                            </li>
		                                        </ul>
		                                    </div>
		                                </li>
		                                <?php endif; ?>
		                                <?php if( ! empty( $settings['social_icon_list'] ) ): ?>
		                                <li>
		                                    <div class="header-social">
		                                    	<?php if(!empty($settings['social_text'])): ?>
		                                        <span class="social-title"><?php echo esc_html($settings['social_text']); ?></span>
		                                        <?php endif; ?>
		                                        <?php foreach( $settings['social_icon_list'] as $social_icon ):
					                          		$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
					                          		$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : ''; 
					                          	?>
		                                        <a <?php echo wp_kses_post( $social_target.$social_nofollow ); ?> href="<?php echo esc_url( $social_icon['icon_link']['url'] ); ?>">
		                                        	<?php \Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] ); ?>		                                        </a>
		                                    	<?php endforeach; ?>
		                                    </div>
		                                </li>
		                                <?php endif; ?>
		                            </ul>
		                        </div>

		                    </div>
		                </div>
		            </div>
		        </div>
		    	<?php endif; ?>

		        <div class="sticky-wrapper">
					<!-- Main Menu Area -->
					<div class="menu-area" data-bg-src="<?php echo esc_url( $settings['header_top_middle_bg_image']['url'] ); ?>">
						<div class="container">
							<div class="row align-items-center justify-content-between">
								<div class="col-auto">
									<div class="header-logo">
										<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
											<?php echo taxiar_img_tag( array(
												'url' => esc_url( $settings['logo_image']['url'] ),
											) ); ?>
										</a>
									</div>
								</div>
								<div class="col-auto">
									<div class="row align-items-center">
										<div class="col-auto">
											<nav class="main-menu d-none d-lg-inline-block <?php echo esc_attr($menu_icon); ?>">
												<?php 
												if( ! empty( $settings['taxseco_menu_select'] ) ){
													wp_nav_menu( $args );
												}  ?>
											</nav>
											<button type="button" class="th-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>
										</div>
										<div class="col-auto d-none d-xxl-block">
											<div class="header-button">
												<?php if( $settings['show_search_btn'] == 'yes' ): ?>
												<button type="button" class="icon-style2 searchBoxToggler"><i class="far fa-search"></i></button>
												<?php endif; ?>
												<?php if(!empty($settings['button_text'])): ?>
												<a href="<?php echo esc_url( $settings['button_url']['url'] ); ?>" class="th-btn style3 style-skew"><span class="btn-text"><?php echo esc_html( $settings['button_text'] ); ?></span></a>
												<?php endif; ?>
												<?php if( $settings['off_canvas'] == 'yes' ): ?>
												<a href="<?php echo esc_url('#'); ?>" class="simple-icon sideMenuToggler"><?php echo wp_kses_post($settings['off_canvas_icon']) ?></a>
												<?php endif; ?>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
						<div class="logo-shape"></div>
					</div>
		        </div>
		    </div>
			<?php
		}else{
	    	echo '<!--==============================Header Area==============================-->';
			echo '<div class="th-header header-layout3">';
				if( $settings['show_header_top'] == 'yes' ){
					$email    	= $settings['email'];
					$phone    	= $settings['phone'];

					$email          = is_email( $email );

					$replace        = array(' ','-',' - ');
					$with           = array('','','');

					$emailurl       = str_replace( $replace, $with, $email );
					$phoneurl       = str_replace( $replace, $with, $phone );
					echo '<div class="header-top">';
						echo '<div class="container">';
							echo '<div class="row gx-0 justify-content-center justify-content-md-between align-items-center">';
								if(!empty($settings['topbar_slogan'])){
									echo '<div class="col-auto">';	                   
										echo '<div class="top-left">';
											echo '<p class="header-notice">'.esc_html($settings['topbar_slogan']).'</p>';
										echo '</div>';
									echo '</div>';
								}

								echo '<div class="col-auto d-none d-md-block">';
									echo '<div class="top-right">';
										echo '<div class="row gx-0 align-items-center justify-content-between">';

											echo '<div class="col-auto">';
												echo '<div class="header-links">';
													echo '<ul>';
														if(!empty($phone)){	 
															echo '<li class="d-none d-lg-inline-block">'.wp_kses_post($settings['phone_icon']).'<a href="'.esc_attr( 'tel:'.$phoneurl ).'">'.esc_html($phone).'</a></li>';
														}
														if(!empty($settings['address'])){
														echo '<li class="d-none d-xxl-inline-block"><a href="'.esc_url($settings['address_url']).'">'.wp_kses_post($settings['address_icon']).''.esc_html($settings['address']).'</a></li>';
														}
														if(!empty($email)){	 
														echo '<li>'.wp_kses_post($settings['email_icon']).'<a href="'.esc_attr( 'mailto:'.$emailurl ).'">'.esc_html($email).'</a></li>';
														}
													echo '</ul>';
												echo '</div>';
											echo '</div>';
											if( ! empty( $settings['social_icon_list'] ) ){
											echo '<div class="col-auto">';
												echo '<div class="header-social">';
													foreach( $settings['social_icon_list'] as $social_icon ){
														$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
														$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';

														echo '<a '.wp_kses_post( $social_target.$social_nofollow ).' href="'.esc_url( $social_icon['icon_link']['url'] ).'">';

														\Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] );

														echo '</a> ';
													}
												echo '</div>';
											echo '</div>';
											}

										echo '</div>';
									echo '</div>';
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}

				echo '<div class="sticky-wrapper">';
					echo '<div class="container">';
						echo '<div class="row gx-0 justify-content-between">';
							if( ! empty( $settings['logo_image']['url'] ) ){
								echo '<div class="col-auto">';
									echo '<div class="header-logo">';
										echo '<a href="'.esc_url( home_url( '/' ) ).'">';
											echo taxiar_img_tag( array(
												'url' => esc_url( $settings['logo_image']['url'] ),
											) );
										echo '</a>';

									echo '</div>';
								echo '</div>';
							}
							echo '<div class="col-auto">';
								echo '<div class="menu-area">';
									echo '<div class="row gx-0 align-items-center justify-content-between">';
										echo '<div class="col-auto">';
											echo '<nav class="main-menu d-none d-lg-inline-block '.esc_attr($menu_icon).'">';                               
												if( ! empty( $settings['taxseco_menu_select'] ) ){
														wp_nav_menu( $args );
													} 
											echo '</nav>';
											echo '<button type="button" class="th-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>';
										echo '</div>';
										echo '<div class="col-auto d-none d-xxl-block">';
											echo '<div class="header-button">';
												if( $settings['show_search_btn'] == 'yes' ){
												echo '<button type="button" class="icon-style2 searchBoxToggler"><i class="far fa-search"></i></button>';
												}
												if( $settings['off_canvas'] == 'yes' ){
												echo '<a href="'.esc_url('#').'" class="simple-icon sideMenuToggler">'.wp_kses_post($settings['off_canvas_icon']).'</a>';
												}

											echo '</div>';
										echo '</div>';
									echo '</div>';
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
			echo '</div>';
		}		
	}
}