<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Service Widget .
 *
 */
class Taxseco_Service extends Widget_Base {

	public function get_name() {
		return 'taxsecoservice';
	}

	public function get_title() {
		return __( 'Services V2', 'taxiar' );
	}

	public function get_icon() {
		return 'th-icon';
    }

	public function get_categories() {
		return [ 'taxiar' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'service_section',
			[
				'label'     => __( 'Service Slider', 'taxiar' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'service_style',
			[
				'label' 	=> __( 'Service Style', 'taxiar' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2' 		=> __( 'Style Two', 'taxiar' ),
					'3' 		=> __( 'Style Three', 'taxiar' ),
					'4' 		=> __( 'Style Four', 'taxiar' ),
					'5' 		=> __( 'Style Five', 'taxiar' ),
				],
			]
		);
		$this->add_control(
			'make_it_slider',
			[
				'label' 		=> __( 'Make It Slider?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Yes', 'taxiar' ),
				'label_off' 	=> __( 'No', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
				'condition' 	=> [
                    'service_style' => '1'
                ]
			]
		);
		$this->add_control(
			'slider_id',
			[
				'label' 		=> __( 'Slider Id?', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> 'serviceSlide2',
				'condition' 	=> [
                    'service_style' => '2'
                ]
			]
		);

		$repeater = new Repeater();

        $repeater->add_control(
			'service_slider_image',
			[
				'label'     => __( 'Service Slider Image', 'taxiar' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'service_slider_icon_image',
			[
				'label'     => __( 'Icon Class', 'taxiar' ),
				'type'      => Controls_Manager::TEXTAREA,
				'rows' 		=> 2,
			]
		);

        $repeater->add_control(
			'service_title',
            [
				'label'         => __( 'Service Title', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Neurology Specialist' , 'taxiar' ),
				'label_block'   => true,
			]
		);
		$repeater->add_control(
			'service_number',
			[
				'label'         => __( 'Service Number', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( '01' , 'taxiar' ),
				'label_block'   => true,
			]
		);
        $repeater->add_control(
			'service_description',
            [
				'label'         => __( 'Service Description', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'There are many variations injected many alteration humour believable.' ,'taxiar' ),
				'label_block'   => true,
			]
		);

        $repeater->add_control(
            'button_text',
            [
                'label'         => __( 'Button Text', 'taxiar' ),
                'type'          => Controls_Manager::TEXTAREA,
                'label_block'   => true,
				'default'		=> __( 'View Details','taxiar' )
            ]
        );

        $repeater->add_control(
            'button_url',
            [
                'label'         => __( 'Button Url', 'taxiar' ),
                'type'          => Controls_Manager::TEXTAREA,
                'label_block'   => true,
				'default'		=> '#'
            ]
        );

		$this->add_control(
			'slides',
			[
				'label' 		=> __( 'Service Slider', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'service_slider_image' 	=> Utils::get_placeholder_image_src(),
					],
					[
						'service_slider_image' 	=> Utils::get_placeholder_image_src(),
					],
				],
				'title_field' 	=> '{{service_title}}',
				'condition' => [
					'service_style!'  => ['5']
				]
			]
		);

		$repeater2 = new Repeater();

        $repeater2->add_control(
			'service_slider_image',
			[
				'label'     => __( 'Service Slider Image', 'taxiar' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater2->add_control(
			'service_slider_icon_image',
			[
				'label'     => __( 'Icon', 'taxiar' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

        $repeater2->add_control(
			'service_title',
            [
				'label'         => __( 'Service Title', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Neurology Specialist' , 'taxiar' ),
				'label_block'   => true,
			]
		);

        $repeater2->add_control(
			'service_description',
            [
				'label'         => __( 'Service Description', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'There are many variations injected many alteration humour believable.' ,'taxiar' ),
				'label_block'   => true,
			]
		);

        $repeater2->add_control(
            'button_text',
            [
                'label'         => __( 'Button Text', 'taxiar' ),
                'type'          => Controls_Manager::TEXTAREA,
                'label_block'   => true,
                'rows' => 2,
				'default'		=> __( 'View Details','taxiar' )
            ]
        );

        $repeater2->add_control(
            'button_url',
            [
               'label' 		=> __( 'Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
            ]
        );

		$this->add_control(
			'slides_2',
			[
				'label' 		=> __( 'Service Slider', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater2->get_controls(),
				'default' 		=> [
					[
						'service_slider_image' 	=> Utils::get_placeholder_image_src(),
					],
					[
						'service_slider_image' 	=> Utils::get_placeholder_image_src(),
					],
				],
				'title_field' 	=> '{{service_title}}',
				'condition' => [
					'service_style'  => ['5']
				]
			]
		);

        $this->end_controls_section();

		/*-----------------------------------------General styling------------------------------------*/

		$this->start_controls_section(
			'service_slider_general_style',
			[
				'label' 	=> __( 'General Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'service_box_background',
			[
				'label' 		=> __( 'Service Box Background', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_content,{{WRAPPER}} .service-card_content,{{WRAPPER}} .service-grid_content' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .service-grid, {{WRAPPER}} .feature-grid:before' => '--smoke-color: {{VALUE}} !important',
                ]
			]
        );
		

		$this->end_controls_section();

		/*-----------------------------------------Feedback styling------------------------------------*/

		$this->start_controls_section(
			'overview_con_styling',
			[
				'label' 	=> __( 'Content Styling', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
        );
        $this->start_controls_tabs(
			'style_tabs2'
		);


		$this->start_controls_tab(
			'style_normal_tab2',
			[
				'label' => esc_html__( 'Number', 'taxiar' ),
			]
		);
        $this->add_control(
			'overview_title_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_number,{{WRAPPER}} .service-card_number,{{WRAPPER}} .service-card_subtitle'	=> 'color: {{VALUE}}!important;',
				],
			]
        );
        $this->add_group_control(
		Group_Control_Typography::get_type(),
		 	[
				'name' 			=> 'overview_title_typography',
		 		'label' 		=> __( 'Typography', 'taxiar' ),
		 		'selector' 	=> '{{WRAPPER}} .service-box_number,{{WRAPPER}} .service-card_number,{{WRAPPER}} .service-card_subtitle',
			]
		);

        $this->add_responsive_control(
			'overview_title_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_number,{{WRAPPER}} .service-card_number,{{WRAPPER}} .service-card_subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'overview_title_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_number,{{WRAPPER}} .service-card_number,{{WRAPPER}} .service-card_subtitle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );
		$this->end_controls_tab();

		//--------------------secound--------------------//

		$this->start_controls_tab(
			'style_hover_tab2',
			[
				'label' => esc_html__( 'Title', 'taxiar' ),
			]
		);
		$this->add_control(
			'overview_content_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_title,{{WRAPPER}} .service-card_title,{{WRAPPER}} .service-grid_title, {{WRAPPER}} h3'	=> 'color: {{VALUE}}!important;',
				],
			]
        );
        $this->add_group_control(
		Group_Control_Typography::get_type(),
		 	[
				'name' 			=> 'overview_content_typography',
		 		'label' 		=> __( 'Typography', 'taxiar' ),
		 		'selector' 	=> '{{WRAPPER}} .service-box_title,{{WRAPPER}} .service-card_title,{{WRAPPER}} .service-grid_title, {{WRAPPER}} h3',
			]
		);

        $this->add_responsive_control(
			'overview_content_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_title,{{WRAPPER}} .service-card_title,{{WRAPPER}} .service-grid_title, {{WRAPPER}} h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'overview_content_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_title,{{WRAPPER}} .service-card_title,{{WRAPPER}} .service-grid_title, {{WRAPPER}} h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

		$this->end_controls_tab();


		//--------------------three--------------------//

		$this->start_controls_tab(
			'style_hover_tab3',
			[
				'label' => esc_html__( 'Description', 'taxiar' ),
			]
		);
		$this->add_control(
			'counter_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_text,{{WRAPPER}} .service-card_text,{{WRAPPER}} .service-grid_text, {{WRAPPER}} p'	=> 'color: {{VALUE}}!important;',
				],
			]
        );
        $this->add_group_control(
		Group_Control_Typography::get_type(),
		 	[
				'name' 			=> 'counter_typography',
		 		'label' 		=> __( 'Typography', 'taxiar' ),
		 		'selector' 	=> '{{WRAPPER}} .service-box_tex,{{WRAPPER}} .service-card_text,{{WRAPPER}} .service-grid_text, {{WRAPPER}} p',
			]
		);

        $this->add_responsive_control(
			'counter_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_text,{{WRAPPER}} .service-card_text,{{WRAPPER}} .service-grid_text, {{WRAPPER}} p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'counter_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .service-box_text,{{WRAPPER}} .service-card_text,{{WRAPPER}} .service-grid_text, {{WRAPPER}} p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );



		$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

			if( $settings['service_style'] == '1' ){
				echo '<div class="service_1 arrow-wrap">';
					if($settings['make_it_slider'] == 'yes'){
						echo '<div class="row th-carousel" data-slide-show="3" data-md-slide-show="2" data-arrows="true">';
					}else{
						echo '<div class="row gy-40">';
					}
	                	foreach( $settings['slides'] as $service_slider ){
	                		echo '<div class="col-md-6 col-lg-4">';
			                    echo '<div class="service-box">';
			                        if( ! empty( $service_slider['service_slider_image']['url'] ) ){
				                        echo '<div class="service-box_img">';
				                            echo taxiar_img_tag( array(
												'url'   => esc_url( $service_slider['service_slider_image']['url'] ),
											) );
				                        echo '</div>';
				                    }
			                        echo '<div class="service-box_content">';
			                        	if( ! empty( $service_slider['service_slider_icon_image'] ) ){
				                            echo '<div class="service-box_icon">'.wp_kses_post($service_slider['service_slider_icon_image']).'</div>';
				                        }
				                        if( ! empty( $service_slider['service_title'] ) ){
				                            echo '<h3 class="service-box_title"><a href="'.esc_url( $service_slider['button_url'] ).'">'.esc_html( $service_slider['service_title'] ).'</a></h3>';
				                        }
			                            if( ! empty( $service_slider['service_description'] ) ){
				                            echo '<p class="service-box_text">'.esc_html( $service_slider['service_description'] ).'</p>';
				                        }
			                        echo '</div>';
			                        if( ! empty( $service_slider['button_text'] ) ){
				                        echo '<a href="'.esc_url( $service_slider['button_url'] ).'" class="th-btn">'.esc_html( $service_slider['button_text'] ).' <i class="fas fa-arrow-right"></i></a>';
				                    }
			                    echo '</div>';
			                echo '</div>';
			            }
		            echo '</div>';
	            echo '</div>';
			}elseif( $settings['service_style'] == '2' ){
				echo '<div class="service_2 arrow-wrap">';
					echo '<div class="row th-carousel" id="'.esc_attr($settings['slider_id']).'" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="2">';
						foreach( $settings['slides'] as $service_slider ){

							echo '<div class="col-md-6 col-lg-4">';
								if( ! empty( $service_slider['service_slider_image']['url'] ) ){
				                    echo '<div class="service-card" data-bg-src="'.esc_url( $service_slider['service_slider_image']['url'] ).'">';
				                }

			                        echo '<div class="service-card_content">';
			                        	if( ! empty( $service_slider['service_slider_icon_image'] ) ){
				                            echo '<div class="service-card_icon">'.wp_kses_post($service_slider['service_slider_icon_image']).'</div>';
				                        }
			                            if( ! empty( $service_slider['service_number'] ) ){
				                            echo '<span class="service-card_subtitle">'.esc_html( $service_slider['service_number'] ).'</span>';
				                        }
			                            if( ! empty( $service_slider['service_title'] ) ){
				                            echo '<h3 class="service-card_title"><a href="'.esc_url( $service_slider['button_url'] ).'">'.esc_html( $service_slider['service_title'] ).'</a></h3>';
				                        }
			                            if( ! empty( $service_slider['service_description'] ) ){
				                            echo '<p class="service-card_text">'.esc_html( $service_slider['service_description'] ).'</p>';
				                        }
				                        if( ! empty( $service_slider['button_text'] ) ){
				                            echo '<a href="'.esc_url( $service_slider['button_url'] ).'" class="th-btn">'.esc_html( $service_slider['button_text'] ).'</a>';
				                        }
			                        echo '</div>';
			                    echo '</div>';
			                echo '</div>';
			            }
		            echo '</div>';
		        echo '</div>';
			}elseif( $settings['service_style'] == '3' ){
				echo '<div class="service_3">';
					echo '<div class="row th-carousel" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="2">';
						foreach( $settings['slides'] as $service_slider ){
				            echo '<div class="col-md-6 col-lg-4">';
				                echo '<div class="service-grid">';
				                	if( ! empty( $service_slider['service_slider_image']['url'] ) ){
				                        echo '<div class="service-grid_img">';
				                            echo taxiar_img_tag( array(
												'url'   => esc_url( $service_slider['service_slider_image']['url'] ),
											) );
				                        echo '</div>';
				                    }
				                    echo '<div class="service-grid_content">';
			                            if( ! empty( $service_slider['service_title'] ) ){
				                            echo '<h3 class="service-grid_title"><a href="'.esc_url( $service_slider['button_url'] ).'">'.esc_html( $service_slider['service_title'] ).'</a></h3>';
				                        }
				                        if( ! empty( $service_slider['service_description'] ) ){
				                            echo '<p class="service-grid_text">'.esc_html( $service_slider['service_description'] ).'</p>';
				                        }
				                        if( ! empty( $service_slider['button_text'] ) ){
					                        echo '<a href="'.esc_url( $service_slider['button_url'] ).'" class="th-btn style-skew"><span class="btn-text">'.esc_html( $service_slider['button_text'] ).' </span></a>';
					                    }
				                    echo '</div>';
				                echo '</div>';
			                echo '</div>';
			            }
		            echo '</div>';
		        echo '</div>';
			}elseif( $settings['service_style'] == '4' ){
				echo '<div class="service_3">';
					echo '<div class="row slider-shadow th-carousel arrow-wrap" data-slide-show="3" data-lg-slide-show="3" data-md-slide-show="2" data-sm-slide-show="1" data-xs-slide-show="1" data-arrows="true">';
						foreach( $settings['slides'] as $service_slider ){
				            echo '<div class="col-md-6 col-lg-4 col-xl-3">';
				                echo '<div class="service-grid">';
				                	if( ! empty( $service_slider['service_slider_image']['url'] ) ){
				                        echo '<div class="service-block_img">';
				                            echo taxiar_img_tag( array(
												'url'   => esc_url( $service_slider['service_slider_image']['url'] ),
											) );
				                        echo '</div>';
				                    }
				                    echo '<div class="service-block_content">';
			                            if( ! empty( $service_slider['service_title'] ) ){
				                            echo '<h3 class="service-block_title"><a href="'.esc_url( $service_slider['button_url'] ).'">'.esc_html( $service_slider['service_title'] ).'</a></h3>';
				                        }
				                        if( ! empty( $service_slider['service_description'] ) ){
				                            echo '<p class="service-block_tex">'.esc_html( $service_slider['service_description'] ).'</p>';
				                        }
				                        if( ! empty( $service_slider['button_text'] ) ){
					                        echo '<a href="'.esc_url( $service_slider['button_url'] ).'" class="layer-btn"><span class="btn-text">'.esc_html( $service_slider['button_text'] ).' </span></a>';
					                    }
				                    echo '</div>';
				                echo '</div>';
			                echo '</div>';
			            }
		            echo '</div>';
		        echo '</div>';
			}else{
			?>
			<div class="row th-carousel slider-shadow" data-slide-show="3" data-lg-slide-show="3" data-md-slide-show="2" data-sm-slide-show="1">
			    <?php foreach( $settings['slides_2'] as $service_slider ): ?>
			    <div class="col-lg-4 col-md-6">
			        <div class="feature-grid">
			            <div class="feature-grid_img">
			                <?php  echo taxiar_img_tag( array(
			    				'url'   => esc_url( $service_slider['service_slider_image']['url'] ),
			    			) ); ?>
			            </div>
			            <div class="feature-grid_icon">
			                <?php  echo taxiar_img_tag( array(
			    				'url'   => esc_url( $service_slider['service_slider_icon_image']['url'] ),
			    			) ); ?>
			            </div>
			            <h3 class="box-title"><?php echo esc_html($service_slider['service_title'] ); ?></h3>
			            <p class="feature-grid_text"><?php echo esc_html($service_slider['service_description'] ); ?></p>
			            <a href="<?php echo esc_url( $service_slider['button_url']['url'] ); ?>" class="th-btn"><?php echo esc_html($service_slider['button_text'] ); ?></a>
			        </div>
			    </div>
				<?php endforeach; ?>
			</div>

			<?php
			}


	}
}