<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Border;
/**
 *
 * Hero Widget.
 *
 */
class Taxiar_Hero extends Widget_Base {

	public function get_name() {
		return 'taxiarhero';
	}
	public function get_title() {
		return __( 'Hero', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar_header_elements' ];
	}

    public function get_as_contact_form(){
        if ( ! class_exists( 'WPCF7' ) ) {
            return;
        }
        $as_cfa         = array();
        $as_cf_args     = array( 'posts_per_page' => -1, 'post_type'=> 'wpcf7_contact_form' );
        $as_forms       = get_posts( $as_cf_args );
        $as_cfa         = ['0' => esc_html__( 'Select Form', 'taxiar' ) ];
        if( $as_forms ){
            foreach ( $as_forms as $as_form ){
                $as_cfa[$as_form->ID] = $as_form->post_title;
            }
        }else{
            $as_cfa[ esc_html__( 'No contact form found', 'taxiar' ) ] = 0;
        }
        return $as_cfa;
    }

	protected function register_controls() {

		$this->start_controls_section(
			'hero_section',
			[
				'label' 	=> __( 'hero', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 		=> __( 'Layout Style', 'taxiar' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options' 		=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2'  		=> __( 'Style Two', 'taxiar' ),
				],
			]
		);

        taxiar_media_fields( $this, 'bg', 'Choose Background', ['1', '2'] );
		taxiar_media_fields( $this, 'image', 'Choose Image', ['1', '2'] );
		taxiar_media_fields( $this, 'image2', 'Choose Shape', ['1', '2'] );
		taxiar_media_fields( $this, 'image3', 'Choose Shape', ['2'] );
		taxiar_media_fields( $this, 'subtitle_shape', 'Subtitle Shape', ['1'] );
		taxiar_general_fields( $this, 'subtitle', 'Subtitle', 'TEXTAREA2', 'Welcome To Taxiar' );
		taxiar_general_fields( $this, 'title', 'Title', 'TEXTAREA', 'Taxiar Exceptional Car Rental' );
		taxiar_general_fields( $this, 'label', 'Label', 'TEXTAREA2', 'Starting From $50 Per Day', ['1'] );
		taxiar_general_fields( $this, 'button_text', 'Button Text', 'TEXT', 'Discover More' );
		taxiar_url_fields( $this, 'button_url', 'Button URL' );
		taxiar_general_fields( $this, 'button_text2', 'Button Text', 'TEXT', 'Watch The Video', ['2'] );
		taxiar_url_fields( $this, 'button_url2', 'Button URL', ['2'] );
        taxiar_social_fields( $this, 'social_lists', 'Social Lists', ['2'] );

        $repeater = new Repeater();

        $repeater->add_control(
            'img',
            [
                'label'     => __( 'Client Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
            ]
        );

        $this->add_control(
			'sliders',
			[
				'label' 		=> __( 'Sliders', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'condition'	=> ['layout_style' => '1']
			]
		);
        taxiar_general_fields( $this, 'client_title', 'Client Title', 'TEXTAREA2', '10k Customers', ['1'] );

        $this->add_control(
            'taxiar_select_contact_form',
            [
                'label'   => esc_html__( 'Select Form', 'taxiar' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '0',
                'options' => $this->get_as_contact_form(),
                'condition'	=> ['layout_style' => '1']
            ]
        );
        taxiar_media_fields( $this, 'shape', 'Choose Image', ['1'] );

		$this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

        //-------------------------General Style-----------------------//
        $this->start_controls_section(
            'style',
            [
                'label' => __( 'Style', 'taxiar' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        taxiar_color_fields( $this, 'bg22', 'Label Background', 'background', '{{WRAPPER}} .hero-rate-title' );  
        taxiar_color_fields( $this, 'bg222', 'Form Background', '--title-color', '{{WRAPPER}} .booking-area4' );  
        
        $this->end_controls_section();

        //-------Subtitle Style-------
		taxiar_common_style_fields( $this, 'subtitle', 'Subtitle', '{{WRAPPER}} .sub', ['1'] );
		//-------Title Style-------
		taxiar_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .title' );
		//-------Label Style-------
		taxiar_common_style_fields( $this, 'label', 'Label', '{{WRAPPER}} .hero-rate-title' );
		//-------Client Title Style-------
		taxiar_common_style_fields( $this, 'title2', 'Client Title', '{{WRAPPER}} .box-title' );
		//------Button Style-------
		taxiar_button_style_fields( $this, '10', 'Button Styling', '{{WRAPPER}} .th_btn' );

    }

	protected function render() {

    $settings = $this->get_settings_for_display();

        if( $settings['layout_style'] == '1' ){
            echo '<div class="th-hero-wrapper  hero-10" data-bg-src="'.esc_url($settings['bg']['url']).'">';
                echo '<div class="container">';
                    echo '<div class="row">';
                        echo '<div class="col-xl-7">';
                            echo '<div class="hero-style10">';
                                if(!empty($settings['subtitle'])){
                                echo '<span class="hero-subtitle sub">';
                                    echo taxiar_img_tag( array(
                                        'url'   => esc_url( $settings['subtitle_shape']['url']  ),
                                    ));
                                    echo wp_kses_post($settings['subtitle']);
                                echo '</span>';
                                }
                                if(!empty($settings['title'])){
                                echo '<h1 class="hero-title title">'.wp_kses_post($settings['title']).'</h1>';
                                }
                                echo '<div class="hero-client-box">';
                                    if(!empty($settings['label'])){
                                    echo '<div class="hero-rate">';
                                        echo '<span class="hero-rate-title">'.wp_kses_post($settings['label']).'</span>';
                                    echo '</div>';
                                    }
                                    echo '<div class="client-thumb">';
                                        echo '<div class="client-thumb-group">';
                                            foreach( $settings['sliders'] as $data ){
                                                echo '<div class="thumb">';
                                                    echo taxiar_img_tag( array(
                                                        'url'   => esc_url( $data['img']['url']  ),
                                                    ));
                                                echo '</div>';
                                            }
                                            if(!empty($settings['sliders'])){
                                            echo '<div class="thumb icon"><i class="fa-regular fa-plus"></i></div>';
                                            }
                                        echo '</div>';
                                        if(!empty($settings['client_title'])){
                                            echo '<span class="box-title">'.wp_kses_post($settings['client_title']).'</span>';
                                        }
                                    echo '</div>';
                                echo '</div>';
                                 
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
                if(!empty($settings['image']['url'])){
                echo '<div class="hero-10-image">';
                    echo '<div class="hero-img1">';
                        echo taxiar_img_tag( array(
                            'url'   => esc_url( $settings['image']['url']  ),
                        ));
                    echo '</div>';
                echo '</div>';
                }
                if(!empty($settings['image2']['url'])){
                echo '<div class="hero-shape">';
                    echo taxiar_img_tag( array(
                        'url'   => esc_url( $settings['image2']['url']  ),
                    ));
                echo '</div>';
                }

                if( !empty($settings['taxiar_select_contact_form']) ){
                echo '<div class="booking-area4 bg-title">';
                    echo '<div class="container">';
                        echo '<div class="booking-form style4 ajax-contact">';
                            echo '<div class="input-wrap style2">';
                                if( !empty($settings['taxiar_select_contact_form']) ){
                                    echo do_shortcode( '[contact-form-7  id="'.$settings['taxiar_select_contact_form'].'"]' ); 
                                }else{
                                    echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'taxiar' ). '</p></div>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                    if(!empty($settings['shape']['url'])){
                        echo '<div class="body-shape">';
                            echo taxiar_img_tag( array(
                                'url'   => esc_url( $settings['shape']['url']  ),
                            ));
                        echo '</div>';
                    }
                echo '</div>';
                }
            echo '</div>';

        }elseif( $settings['layout_style'] == '2' ){
            echo '<div class="main-content hero-11 section-item" data-bg-src="'.esc_url($settings['bg']['url']).'">';
                echo '<div class="container">';
                    echo '<div class="row align-items-center">';
                        echo '<div class="col-xl-6">';
                            echo '<div class="hero-style11">';
                                if(!empty($settings['subtitle'])){
                                    echo '<span class="hero-subtitle2 sub">';
                                        echo wp_kses_post($settings['subtitle']);
                                    echo '</span>';
                                }
                                if(!empty($settings['title'])){
                                echo '<h1 class="hero-title title">'.wp_kses_post($settings['title']).'</h1>';
                                }
                                echo '<div class="btn-group">';
                                    if(!empty($settings['button_text'])){
                                        echo '<a href="'.esc_url( $settings['button_url']['url'] ).'" class="th-btn th_btn style3 radius-btn3">'.wp_kses_post($settings['button_text']).'</a>';
                                    }
                                    if(!empty($settings['button_text2'])){
                                    echo '<div class="call-btn">';
                                        if(!empty($settings['button_url2']['url'])){
                                            echo '<a href="'.esc_url( $settings['button_url2']['url'] ).'" class="play-btn popup-video"><i class="fas fa-play"></i></a>';
                                        }
                                        echo '<div class="media-body">';
                                            echo '<a href="'.esc_url( $settings['button_url2']['url'] ).'" class="btn-title popup-video">'.wp_kses_post($settings['button_text2']).'</a>';
                                        echo '</div>';
                                    echo '</div>';
                                    }
                                echo '</div>';
                                echo '<div class="hero-social-wrapp">';
                                    echo '<div class="hero-social">';
                                        foreach( $settings['social_lists'] as $social_icon ){
                                            $social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
                                            $social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';

                                            echo '<a '.wp_kses_post( $social_target.$social_nofollow ).' href="'.esc_url( $social_icon['icon_link']['url'] ).'">';

                                            \Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] );
                        
                                            echo '</a> ';
                                        }
                                    echo '</div>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                        echo '<div class="col-xl-6">';
                            echo '<div class="hero-img-1">';
                                    if(!empty($settings['image']['url'])){
                                    echo '<div class="thumb">';
                                        echo taxiar_img_tag( array(
                                            'url'   => esc_url( $settings['image']['url']  ),
                                        ));
                                    echo '</div>';
                                    }
                                    if(!empty($settings['image2']['url'])){
                                    echo '<div class="hero-shape">';
                                        echo taxiar_img_tag( array(
                                            'url'   => esc_url( $settings['image2']['url']  ),
                                        ));
                                    echo '</div>';
                                    }
                                    if(!empty($settings['image3']['url'])){
                                    echo '<div class="hero-shape2">';
                                        echo taxiar_img_tag( array(
                                            'url'   => esc_url( $settings['image3']['url']  ),
                                        ));
                                    echo '</div>';
                                    }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';

        }
 
		
	}

}