<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
/**
 *
 * Image Widget .
 *
 */
class taxiar_Image extends Widget_Base {

	public function get_name() {
		return 'taxiarimage';
	}
	public function get_title() {
		return __( 'Image', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'image_section',
			[
				'label' 	=> __( 'Image', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'taxiar' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2' 		=> __( 'Style Two', 'taxiar' ),
					'3' 		=> __( 'Style Three', 'taxiar' ),
					'4' 		=> __( 'Style Four', 'taxiar' ),
					'5' 		=> __( 'Style Five', 'taxiar' ),
					'6' 		=> __( 'Style Six', 'taxiar' ),
					'7' 		=> __( 'Style Seven', 'taxiar' ),
				],
			]
		);

        $this->add_control(
			'image',
			[
				'label' 		=> __( 'Choose Image', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 			=> Utils::get_placeholder_image_src(),
				],
			]
		);   

		$this->add_control(
			'image2',
			[
				'label' 		=> __( 'Choose Image', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 			=> Utils::get_placeholder_image_src(),
				],
				'condition'	=> [
					'layout_style' => ['1', '4', '7'],
				]
			]
		);  
		$this->add_control(
			'image3',
			[
				'label' 		=> __( 'Choose Image', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'dynamic' 		=> [
					'active' 		=> true,
				],
				'condition'	=> [
					'layout_style' => ['7'],
				]
			]
		);  

		$this->add_control(
			'title',
            [
				'label'         => __( 'Title', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Title here' , 'taxiar' ),
				'label_block'   => true,
				'rows' 		=> 3,
				'condition'	=> [
					'layout_style' => ['1','2','4', '7'],
				]
			]
		);
		
		$this->add_control(
			'desc',
            [
				'label'         => __( 'Description', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( '' , 'taxiar' ),
				'label_block'   => true,
				'rows' 		=> 2,
				'condition'	=> [
					'layout_style' => ['1','2', '4'],
				]
			]
		);

		$this->add_control(
			'video_link',
			[
				'label' 		=> esc_html__( 'Video URL', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition'	=> [
					'layout_style' => ['7'],
				]
			]
		);

       $this->end_controls_section();

      	//---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		taxiar_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .th-title', ['1', '2', '4', '7'] );
		taxiar_common_style_fields( $this, 'desc', 'Description', '{{WRAPPER}} .th-desc', ['1', '2', '4'] );

	}

	protected function render() {

	$settings = $this->get_settings_for_display();
	?>

		<?php if( $settings['layout_style'] == '2' ): ?>
			<div class="img-box8">
				<div class="img1">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image']['url'] ),
					)); ?>
				</div>
				<div class="year-counter">
					<div class="year-counter_number th-title"><?php echo wp_kses_post($settings['title']); ?></div>
					<div class="media-body th-desc"><span class="year-counter_title"><?php echo wp_kses_post($settings['desc']); ?></span></div>
				</div>
        	</div>

		<?php elseif( $settings['layout_style'] == '3' ): ?>
			<div class="taxi-image">
				<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image']['url'] ),
					)); ?>
			</div>

		<?php elseif( $settings['layout_style'] == '4' ): ?>
			<div class="img-box4 style3 pe-xl-4 me-xl-4">
				<div class="img1">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image']['url'] ),
					)); ?>
				</div>
				<div class="img2">
					<?php echo taxiar_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						)); ?>
				</div>
				<div class="th-experience">
					<h3 class="experience-year th-title"><?php echo wp_kses_post($settings['title']); ?></h3>
					<p class="experience-text th-desc"><?php echo wp_kses_post($settings['desc']); ?></p>
				</div>
			</div>
		
		<?php elseif( $settings['layout_style'] == '5' ): ?>
			<div class="app-mockup download-mockup">
				<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image']['url'] ),
					)); ?>
			</div>

		<?php elseif( $settings['layout_style'] == '6' ): ?>
			<div class="img-box9">
				<div class="img1">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image']['url'] ),
					)); ?>
				</div>
			</div>

		<?php elseif( $settings['layout_style'] == '7' ): ?>
			<div class="img-box10" data-bg-src="<?php echo esc_url( $settings['image3']['url'] ); ?>">
				<div class="img1">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image']['url'] ),
					)); ?>
				</div>
				<div class="img2">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image2']['url'] ),
					)); ?>
					<?php if(!empty($settings['video_link']['url'])): ?>
					<a href="<?php echo esc_url( $settings['video_link']['url'] ); ?>" class="play-btn popup-video"><i class="fas fa-play"></i></a>
					<?php endif; ?>
				</div>
				<?php if(!empty($settings['title'])): ?>
				<div class="year-counter">
					<div class="media-body th-title"><?php echo wp_kses_post($settings['title']); ?></div>
				</div>
				<?php endif; ?>
			</div>

		<?php else: ?>
			<div class="img-box7">
				<div class="img1">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image']['url'] ),
					)); ?>
				</div>
				<div class="img2">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $settings['image2']['url'] ),
					)); ?>
				</div>
				<div class="journey-box">
					<h3 class="journey-title th-title"><?php echo wp_kses_post($settings['title']); ?></h3>
					<span class="journey-year th-desc"><?php echo wp_kses_post($settings['desc']); ?></span>
				</div>
			</div>
      
    <?php endif;
	
	}

}