<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Menu Select Widget .
 *
 */
class Taxiar_Menu extends Widget_Base {

	public function get_name() {
		return 'taxiarmenuselect';
	}
	public function get_title() {
		return __( 'Menu Select', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar' ];
	}

	protected function register_controls() {

		 $this->start_controls_section(
			'section_title_section',
			[
				'label'		 	=> __( 'Navigation Menu', 'taxiar' ),
				'tab' 			=> Controls_Manager::TAB_CONTENT,
			]
        );

		taxiar_select_field( $this, 'layout_style', 'Layout Style',[ 'Style One', 'Style Two', 'Style Three', 'Style Four' ] );

		taxiar_general_fields( $this, 'title', 'Title', 'TEXT', 'Title', ['3'] );

		$repeater = new Repeater();

        $repeater->add_control(
			'icon',
            [
				'label'         => __( 'Icon', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( '<i class="fa fa-home"></i>' , 'taxiar' ),
				'label_block'   => true,
				'rows' => '2'
			]
		);
        $repeater->add_control(
			'title',
            [
				'label'         => __( 'Title', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Home' , 'taxiar' ),
				'label_block'   => true,
				'rows' => '2'
			]
		);
        $repeater->add_control(
			'nav_id',
            [
				'label'         => __( 'Menu ID', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( '#home' , 'taxiar' ),
				'label_block'   => true,
				'rows' => '2'
			]
		);

		$this->add_control(
			'onepage_nav_list',
			[
				'label' 		=> __( 'Menu List', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'condition'	=> [
					'layout_style' => ['4'],
				]
			]
		);


		$menus = $this->taxiar_menu_select();

		if( !empty( $menus ) ){
	        $this->add_control(
				'taxiar_menu_select',
				[
					'label'     	=> __( 'Select Taxiar Menu', 'taxiar' ),
					'type'      	=> Controls_Manager::SELECT,
					'options'   	=> $menus,
					'description' 	=> sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'taxiar' ), admin_url( 'nav-menus.php' ) ),
					'condition'		=> [ 
						'layout_style' => ['1', '2', '3']
					],
				]
			);
		}else {
			$this->add_control(
				'no_menu',
				[
					'type' 				=> Controls_Manager::RAW_HTML,
					'raw' 				=> '<strong>' . __( 'There are no menus in your site.', 'taxiar' ) . '</strong><br>' . sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'taxiar' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
					'separator' 		=> 'after',
					'content_classes' 	=> 'elementor-panel-alert elementor-panel-alert-info',
				]
			);
		}

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		taxiar_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .widget_title', ['3'] );


	}

    public function taxiar_menu_select(){ 
	    $taxiar_menu = wp_get_nav_menus();
	    $menu_array  = array();
		$menu_array[''] = __( 'Select A Menu', 'taxiar' );
	    foreach( $taxiar_menu as $menu ){
	        $menu_array[ $menu->slug ] = $menu->name;
	    }
	    return $menu_array;
	}

	protected function render() {

	$settings = $this->get_settings_for_display();

        //Menu by menu select
        $taxiar_avaiable_menu   = $this->taxiar_menu_select();

        if( ! $taxiar_avaiable_menu ){
            return;
        }
        $args = [
            'menu' 		=> $settings['taxiar_menu_select'],
            'menu_class' 	=> 'taxiar-menu',
            'container' 	=> '',
        ];

		if( $settings['layout_style'] == '1' ){
			if( ! empty( $settings['taxiar_menu_select'] ) ){
                wp_nav_menu( $args );
            } 

		}elseif( $settings['layout_style'] == '2' ){
			echo '<div class="footer-links">';
				if( ! empty( $settings['taxiar_menu_select'] ) ){
					wp_nav_menu( $args );
				} 
			echo '</div>';

		}elseif( $settings['layout_style'] == '3' ){
			echo '<div class="widget widget_nav_menu footer-widget">';
				if( !empty($settings['title']) ){
					echo '<h3 class="widget_title">'.esc_html($settings['title']).'</h3>';
				}
				echo '<div class="menu-all-pages-container">';
						if( ! empty( $settings['taxiar_menu_select'] ) ){
							wp_nav_menu( $args );
						} 
				echo '</div>';
            echo '</div>';
		}elseif( $settings['layout_style'] == '4' ){
			echo '<div class="driver-portfolio-menu header  onepage-nav" id="navbar-collapse-toggle">';
				echo '<!-- Fixed Navigation Starts -->';
				echo '<ul class="icon-menu ">';
					foreach( $settings['onepage_nav_list'] as $key => $data ){
						$active = ($key == 0) ? 'active':'';
					echo '<li class="icon-box '.esc_attr($active).'">';
						echo wp_kses_post($data['icon']);
						echo '<a class="smooth-menu" href="'.esc_attr($data['nav_id']).'">';
							echo '<span class="menu-text">'.esc_html($data['title']).'</span>';
						echo '</a>';
					echo '</li>';
					}
				echo '</ul>';
				echo '<!-- Fixed Navigation Ends -->';
			echo '</div>';

		}else{
			if( ! empty( $settings['taxiar_menu_select'] ) ){
				wp_nav_menu( $args );
			}
		}


	}

}